@@ -1,15 +1,3 @@
-# -*- coding: utf-8 -*-
-
-########################################################################
-#
-# License: BSD
-# Created: January 15, 2007
-# Author:  Ivan Vilata i Balaguer - ivan at selidor dot net
-#
-# $Id$
-#
-########################################################################
-
 """Functionality related with node paths in a PyTables file.
 
 Variables
@@ -19,25 +7,17 @@ Variables
     The format of documentation strings in this module.
 
 """
-from __future__ import absolute_import
 
-# Imports
-# =======
 import re
 import warnings
 import keyword
 
 from .exceptions import NaturalNameWarning
-import six
 
-# Public variables
-# ================
 __docformat__ = 'reStructuredText'
 """The format of documentation strings in this module."""
 
 
-# Private variables
-# =================
 _python_id_re = re.compile('^[a-zA-Z_][a-zA-Z0-9_]*$')
 """Python identifier regular expression."""
 
@@ -66,25 +46,24 @@ not.
 
 _warnInfo = (
         "you will not be able to use natural naming to access this object; "
-        "using ``getattr()`` will still work, though")  
+        "using ``getattr()`` will still work, though")
 """Warning printed when a name will not be reachable through natural naming"""
 
-# Public functions
-# ================
 
 def check_attribute_name(name):
-    """Check the validity of the `name` of an attribute in AttributeSet.    
-    
+    """Check the validity of the `name` of an attribute in AttributeSet.
+
     If the name is not valid, a ``ValueError`` is raised.  If it is
     valid but it can not be used with natural naming, a
     `NaturalNameWarning` is issued.
-    
+
+    >>> warnings.simplefilter("ignore")
     >>> check_attribute_name('a')
     >>> check_attribute_name('a_b')
-    >>> check_attribute_name('a:b')
-    >>> check_attribute_name('/a/b')
-    >>> check_attribute_name('/')
-    >>> check_attribute_name('.')
+    >>> check_attribute_name('a:b')         # NaturalNameWarning
+    >>> check_attribute_name('/a/b')        # NaturalNameWarning
+    >>> check_attribute_name('/')           # NaturalNameWarning
+    >>> check_attribute_name('.')           # NaturalNameWarning
     >>> check_attribute_name('__members__')
     Traceback (most recent call last):
      ...
@@ -98,24 +77,24 @@ def check_attribute_name(name):
      ...
     ValueError: the empty string is not allowed as an object name
     """
-    if not isinstance(name, six.string_types):  # Python >= 2.3
-        raise TypeError("object name is not a string: %r" % (name,))
-    
+    if not isinstance(name, str):  # Python >= 2.3
+        raise TypeError(f"object name is not a string: {name!r}")
+
     if name == '':
         raise ValueError("the empty string is not allowed as an object name")
-    
+
     # Check whether `name` is a valid Python identifier.
     if not _python_id_re.match(name):
         warnings.warn("object name is not a valid Python identifier: %r; "
                       "it does not match the pattern ``%s``; %s"
                       % (name, _python_id_re.pattern, _warnInfo),
-                      NaturalNameWarning)
+                      NaturalNameWarning, stacklevel=2)
         return
 
     # However, Python identifiers and keywords have the same form.
     if keyword.iskeyword(name):
         warnings.warn("object name is a Python keyword: %r; %s"
-                      % (name, _warnInfo), NaturalNameWarning)
+                      % (name, _warnInfo), NaturalNameWarning, stacklevel=2)
         return
 
     # Still, names starting with reserved prefixes are not allowed.
@@ -127,7 +106,7 @@ def check_attribute_name(name):
     # ``__members__`` is the only exception to that rule.
     if name == '__members__':
         raise ValueError("``__members__`` is not allowed as an object name")
-    
+
 
 def check_name_validity(name):
     """Check the validity of the `name` of a Node object, which more limited
@@ -136,10 +115,11 @@ def check_name_validity(name):
     If the name is not valid, a ``ValueError`` is raised.  If it is
     valid but it can not be used with natural naming, a
     `NaturalNameWarning` is issued.
-    
+
+    >>> warnings.simplefilter("ignore")
     >>> check_name_validity('a')
     >>> check_name_validity('a_b')
-    >>> check_name_validity('a:b')
+    >>> check_name_validity('a:b')          # NaturalNameWarning
     >>> check_name_validity('/a/b')
     Traceback (most recent call last):
      ...
@@ -163,10 +143,6 @@ def check_name_validity(name):
     elif '/' in name:
         raise ValueError("the ``/`` character is not allowed "
                          "in object names: %r" % name)
-    
-
-
-
 
 
 def join_path(parentpath, name):
@@ -191,15 +167,14 @@ def join_path(parentpath, name):
     if parentpath == '/' and name.startswith('/'):
         pstr = '%s' % name
     elif parentpath == '/' or name.startswith('/'):
-        pstr = '%s%s' % (parentpath, name)
+        pstr = f'{parentpath}{name}'
     else:
-        pstr = '%s/%s' % (parentpath, name)
+        pstr = f'{parentpath}/{name}'
     if pstr.endswith('/'):
         pstr = pstr[:-1]
     return pstr
 
 
-
 def split_path(path):
     """Split a *canonical* `path` into a parent path and a node name.
 
@@ -223,23 +198,18 @@ def split_path(path):
     return (ppath, name)
 
 
-
 def isvisiblename(name):
     """Does this `name` make the named node a visible one?"""
 
     return _hidden_name_re.match(name) is None
 
 
-
 def isvisiblepath(path):
     """Does this `path` make the named node a visible one?"""
 
     return _hidden_path_re.search(path) is None
 
 
-
-# Main part
-# =========
 def _test():
     """Run ``doctest`` on this module."""
 
